import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import cdktf._jsii
import cdktf_cdktf_provider_google._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "cdktf-gitlab-runner",
    "0.0.119",
    __name__[0:-6],
    "cdktf-gitlab-runner@0.0.119.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
